@@ -238,6 +238,22 @@ const LpcFamilyMemoryMap lpcFamilyMemoryMap12xx = {
 	.blockSizes = { 4, 512, 1024, 4096 }		// LPC1200 can write very small (4B) pages/blocks, 4096B max
 };
 
+//SLICE
+const LpcFamilyMemoryMap lpcFamilyMemoryMap13xx = {
+	.addressFlash = 0,
+	.addressRams = { 0x10000000, },
+	.sectorArrays = { { .sizeK=4, .n=8 }, { }, },
+	.blockSizes = { 256, 512, 1024, 4096 }
+};
+
+//SLICE
+const LpcFamilyMemoryMap lpcFamilyMemoryMap13x5_6_7 = {
+	.addressFlash = 0,
+	.addressRams = { 0x10000000, 0x20000000, 0x20004000 },	// RAM1/2 powered off at boot-up
+	.sectorArrays = { { .sizeK=4, .n=16 }, { }, },
+	.blockSizes = { 256, 512, 1024, 4096 }
+};
+
 //SLICE
 const LpcFamilyMemoryMap lpcFamilyMemoryMap17xx = {
 	.addressFlash = 0,
@@ -246,6 +262,14 @@ const LpcFamilyMemoryMap lpcFamilyMemoryMap17xx = {
 	.blockSizes = { 256, 512, 1024, 4096 }
 };
 
+//SLICE
+const LpcFamilyMemoryMap lpcFamilyMemoryMap1788 = {
+	.addressFlash = 0,
+	.addressRams = { 0x10000000, 0x20000000, },
+	.sectorArrays = { { .sizeK=4, .n=16 }, { .sizeK=32, .n=14 }, { }, },
+	.blockSizes = { 256, 512, 1024, 4096 }
+};
+
 //SLICE
 const LpcFamilyMemoryMap lpcFamilyMemoryMap2103 = {
 	.addressFlash = 0,
@@ -378,7 +402,6 @@ const LpcFamilyMember* const lpcFamilyMembers11xx[] = {
 	&lpcFamilyMember11E36_M501_FN33_FBD64,
 	&lpcFamilyMember11E37_M401_FBD64,
 	&lpcFamilyMember11E37_M501_FBD48_FBD64,
-
 	0
 };
 
@@ -394,6 +417,24 @@ const LpcFamilyMember* const lpcFamilyMembers12xx[] = {
 	0
 };
 
+//SLICE
+const LpcFamilyMember* const lpcFamilyMembers13xx[] = {
+	&lpcFamilyMember1311,
+	&lpcFamilyMember1311_01,
+	&lpcFamilyMember1313,
+	&lpcFamilyMember1313_01,
+	&lpcFamilyMember1342,
+	&lpcFamilyMember1343,
+
+	&lpcFamilyMember1315,
+	&lpcFamilyMember1316,
+	&lpcFamilyMember1317,
+	&lpcFamilyMember1345,
+	&lpcFamilyMember1346,
+	&lpcFamilyMember1347,
+	0
+};
+
 //SLICE
 const LpcFamilyMember* const lpcFamilyMembers17xx[] = {
 	&lpcFamilyMember1751,
@@ -408,6 +449,15 @@ const LpcFamilyMember* const lpcFamilyMembers17xx[] = {
 	&lpcFamilyMember1767,
 	&lpcFamilyMember1768,
 	&lpcFamilyMember1769,
+
+	&lpcFamilyMember1774,
+	&lpcFamilyMember1776,
+	&lpcFamilyMember1777,
+	&lpcFamilyMember1778,
+	&lpcFamilyMember1785,
+	&lpcFamilyMember1786,
+	&lpcFamilyMember1787,
+	&lpcFamilyMember1788,
 	0
 };
 
@@ -539,6 +589,21 @@ const LpcFamilyMember* const lpcFamilyMembersXxxx[] = {
 	&lpcFamilyMember1226_M301,
 	&lpcFamilyMember1227_M301,
 
+	&lpcFamilyMember1311,
+	&lpcFamilyMember1311_01,
+	&lpcFamilyMember1313,
+	&lpcFamilyMember1313_01,
+	&lpcFamilyMember1342,
+	&lpcFamilyMember1343,
+
+	&lpcFamilyMember1315,
+	&lpcFamilyMember1316,
+	&lpcFamilyMember1317,
+	&lpcFamilyMember1345,
+	&lpcFamilyMember1346,
+	&lpcFamilyMember1347,
+
+
 	&lpcFamilyMember17,
 	&lpcFamilyMember1751,
 	&lpcFamilyMember1752,
@@ -552,6 +617,16 @@ const LpcFamilyMember* const lpcFamilyMembersXxxx[] = {
 	&lpcFamilyMember1767,
 	&lpcFamilyMember1768,
 	&lpcFamilyMember1769,
+	&lpcFamilyMember1774,
+	&lpcFamilyMember177,
+	&lpcFamilyMember1776,
+	&lpcFamilyMember1777,
+	&lpcFamilyMember1778,
+	&lpcFamilyMember178,
+	&lpcFamilyMember1785,
+	&lpcFamilyMember1786,
+	&lpcFamilyMember1787,
+	&lpcFamilyMember1788,
 
 	&lpcFamilyMember2101,
 	&lpcFamilyMember2102,
@@ -1158,14 +1233,110 @@ const LpcFamilyMember lpcFamilyMember1227_M301 = {
 ////////////////////////////////////////////////////////////////////////////////////////////////////
 // LPC1300 family
 
-/*
-   { 0x2C42502B,  "1311",           8,   4,  SectorTable_17xx, CHIP_VARIANT_LPC13XX },
-   { 0x1816902B,  "1311/01",        8,   4,  SectorTable_17xx, CHIP_VARIANT_LPC13XX },
-   { 0x2C40102B,  "1313",          32,   8,  SectorTable_17xx, CHIP_VARIANT_LPC13XX },
-   { 0x1830102B,  "1313/01",       32,   8,  SectorTable_17xx, CHIP_VARIANT_LPC13XX },
-   { 0x3D01402B,  "1342",          16,   4,  SectorTable_17xx, CHIP_VARIANT_LPC13XX },
-   { 0x3D00002B,  "1343",          32,   8,  SectorTable_17xx, CHIP_VARIANT_LPC13XX },
-*/
+const LpcFamilyMember lpcFamilyMember13xx = {	// least common denominator
+	.name = "LPC13*",
+	.sizeFlashK = 8,
+	.sizeRamKs = { 4, },
+	.id = 0,
+	.familyMemoryMap = &lpcFamilyMemoryMap13xx,
+};
+
+const LpcFamilyMember lpcFamilyMember1311 = {
+	.name = "LPC1311",
+	.sizeFlashK = 8,
+	.sizeRamKs = { 4, },
+	.id = LPC_ID_1311,
+	.familyMemoryMap = &lpcFamilyMemoryMap13xx,
+};
+
+const LpcFamilyMember lpcFamilyMember1311_01 = {
+	.name = "LPC1311/01",
+	.sizeFlashK = 8,
+	.sizeRamKs = { 4, },
+	.id = LPC_ID_1311_01,
+	.familyMemoryMap = &lpcFamilyMemoryMap13xx,
+};
+
+const LpcFamilyMember lpcFamilyMember1313 = {
+	.name = "LPC1313",
+	.sizeFlashK = 32,
+	.sizeRamKs = { 8, },
+	.id = LPC_ID_1313,
+	.familyMemoryMap = &lpcFamilyMemoryMap13xx,
+};
+
+const LpcFamilyMember lpcFamilyMember1313_01 = {
+	.name = "LPC1313/01",
+	.sizeFlashK = 32,
+	.sizeRamKs = { 8, },
+	.id = LPC_ID_1313_01,
+	.familyMemoryMap = &lpcFamilyMemoryMap13xx,
+};
+
+const LpcFamilyMember lpcFamilyMember1342 = {
+	.name = "LPC1342",
+	.sizeFlashK = 16,
+	.sizeRamKs = { 4, },
+	.id = LPC_ID_1342,
+	.familyMemoryMap = &lpcFamilyMemoryMap13xx,
+};
+
+const LpcFamilyMember lpcFamilyMember1343 = {
+	.name = "LPC1343",
+	.sizeFlashK = 32,
+	.sizeRamKs = { 8, },
+	.id = LPC_ID_1343,
+	.familyMemoryMap = &lpcFamilyMemoryMap13xx,
+};
+
+
+const LpcFamilyMember lpcFamilyMember1315 = {
+	.name = "LPC1315",
+	.sizeFlashK = 32,
+	.sizeRamKs = { 8, },
+	.id = LPC_ID_1315,
+	.familyMemoryMap = &lpcFamilyMemoryMap13x5_6_7
+};
+
+const LpcFamilyMember lpcFamilyMember1316 = {
+	.name = "LPC1316",
+	.sizeFlashK = 48,
+	.sizeRamKs = { 8, },
+	.id = LPC_ID_1316,
+	.familyMemoryMap = &lpcFamilyMemoryMap13x5_6_7
+};
+
+const LpcFamilyMember lpcFamilyMember1317 = {
+	.name = "LPC1317",
+	.sizeFlashK = 64,
+	.sizeRamKs = { 8, 0, 2 },
+	.id = LPC_ID_1317,
+	.familyMemoryMap = &lpcFamilyMemoryMap13x5_6_7
+};
+
+const LpcFamilyMember lpcFamilyMember1345 = {
+	.name = "LPC1345",
+	.sizeFlashK = 32,
+	.sizeRamKs = { 8, 2, },
+	.id = LPC_ID_1345,
+	.familyMemoryMap = &lpcFamilyMemoryMap13x5_6_7
+};
+
+const LpcFamilyMember lpcFamilyMember1346 = {
+	.name = "LPC1346",
+	.sizeFlashK = 48,
+	.sizeRamKs = { 8, 2, },
+	.id = LPC_ID_1346,
+	.familyMemoryMap = &lpcFamilyMemoryMap13x5_6_7
+};
+
+const LpcFamilyMember lpcFamilyMember1347 = {
+	.name = "LPC1347",
+	.sizeFlashK = 64,
+	.sizeRamKs = { 8, 2, 2 },
+	.id = LPC_ID_1347,
+	.familyMemoryMap = &lpcFamilyMemoryMap13x5_6_7
+};
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////
 // LPC1700 family
@@ -1306,6 +1477,86 @@ const LpcFamilyMember lpcFamilyMember1769 = {
 	.familyMemoryMap = &lpcFamilyMemoryMap17xx
 };
 
+const LpcFamilyMember lpcFamilyMember177 = {
+	.name = "LPC177*",
+	.sizeFlashK = 128,
+	.sizeRamKs = { 32, 8, },
+	.id = 0,
+	.familyMemoryMap = &lpcFamilyMemoryMap1788
+};
+
+const LpcFamilyMember lpcFamilyMember1774 = {
+	.name = "LPC1774",
+	.sizeFlashK = 128,
+	.sizeRamKs = { 32, 8, },
+	.id = LPC_ID_1774,
+	.familyMemoryMap = &lpcFamilyMemoryMap1788
+};
+
+const LpcFamilyMember lpcFamilyMember1776 = {
+	.name = "LPC1776",
+	.sizeFlashK = 256,
+	.sizeRamKs = { 64, 16, },
+	.id = LPC_ID_1776,
+	.familyMemoryMap = &lpcFamilyMemoryMap1788
+};
+
+const LpcFamilyMember lpcFamilyMember1777 = {
+	.name = "LPC1777",
+	.sizeFlashK = 512,
+	.sizeRamKs = { 64, 32, },
+	.id = LPC_ID_1777,
+	.familyMemoryMap = &lpcFamilyMemoryMap1788
+};
+
+const LpcFamilyMember lpcFamilyMember1778 = {
+	.name = "LPC1778",
+	.sizeFlashK = 512,
+	.sizeRamKs = { 64, 32, },
+	.id = LPC_ID_1778,
+	.familyMemoryMap = &lpcFamilyMemoryMap1788
+};
+
+const LpcFamilyMember lpcFamilyMember178 = {
+	.name = "LPC178*",
+	.sizeFlashK = 256,
+	.sizeRamKs = { 64, 16, },
+	.id = 0,
+	.familyMemoryMap = &lpcFamilyMemoryMap1788
+};
+
+const LpcFamilyMember lpcFamilyMember1785 = {
+	.name = "LPC1785",
+	.sizeFlashK = 256,
+	.sizeRamKs = { 64, 16, },
+	.id = LPC_ID_1785,
+	.familyMemoryMap = &lpcFamilyMemoryMap1788
+};
+
+const LpcFamilyMember lpcFamilyMember1786 = {
+	.name = "LPC1786",
+	.sizeFlashK = 256,
+	.sizeRamKs = { 64, 16, },
+	.id = LPC_ID_1786,
+	.familyMemoryMap = &lpcFamilyMemoryMap1788
+};
+
+const LpcFamilyMember lpcFamilyMember1787 = {
+	.name = "LPC1787",
+	.sizeFlashK = 512,
+	.sizeRamKs = { 64, 16, },
+	.id = LPC_ID_1787,
+	.familyMemoryMap = &lpcFamilyMemoryMap1788
+};
+
+const LpcFamilyMember lpcFamilyMember1788 = {
+	.name = "LPC1788",
+	.sizeFlashK = 512,
+	.sizeRamKs = { 64, 16, },
+	.id = LPC_ID_1788,
+	.familyMemoryMap = &lpcFamilyMemoryMap1788
+};
+
 ////////////////////////////////////////////////////////////////////////////////////////////////////
 //LPC210x family
 //SLICE
